@@ -16,7 +16,7 @@ class Transform(Step.Step):
 
 
     def startup(self):
-        super(self).startup()
+        super(Transform,self).startup()
         self.startSubscriber()
 
     def doWorkAndHandoff(self):
